@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminRegistration;
@@ -11,11 +11,7 @@ package Kernel::Modules::AdminRegistration;
 use strict;
 use warnings;
 
-use Kernel::System::Environment;
-use Kernel::System::Registration;
-use Kernel::System::SystemData;
-use Kernel::System::OTRSBusiness;
-use Kernel::System::PID;
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -26,66 +22,78 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for my $Needed (qw(ParamObject LayoutObject ConfigObject LogObject SessionObject)) {
-        if ( !$Self->{$Needed} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
-        }
-    }
-    $Self->{EnvironmentObject}  = Kernel::System::Environment->new(%Param);
-    $Self->{RegistrationObject} = Kernel::System::Registration->new(%Param);
-    $Self->{SystemDataObject}   = Kernel::System::SystemData->new(%Param);
-    $Self->{OTRSBusinessObject} = Kernel::System::OTRSBusiness->new(%Param);
-    $Self->{PIDObject}          = Kernel::System::PID->new(%Param);
-
-    $Self->{RegistrationState} = $Self->{SystemDataObject}->SystemDataGet(
-        Key => 'Registration::State',
-    ) || '';
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # if system is not yet registered, subaction should be 'register'
-    if ( $Self->{RegistrationState} ne 'registered' ) {
+    # get needed objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    # check if cloud services are disabled
+    my $CloudServicesDisabled = $ConfigObject->Get('CloudServices::Disabled') || 0;
+
+    if ($CloudServicesDisabled) {
+
+        my $Output = $LayoutObject->Header(
+            Title => Translatable('Error'),
+        );
+        $Output .= $LayoutObject->Output(
+            TemplateFile => 'CloudServicesDisabled',
+            Data         => \%Param
+        );
+        $Output .= $LayoutObject->Footer();
+        return $Output
+    }
+
+    my $RegistrationState = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet(
+        Key => 'Registration::State',
+    ) || '';
+
+    # if system is not yet registered, sub-action should be 'register'
+    if ( $RegistrationState ne 'registered' ) {
 
         $Self->{Subaction} ||= 'OTRSIDValidate';
 
-        # subaction can't be 'Deregister' or UpdateNow
+        # sub-action can't be 'Deregister' or UpdateNow
         if ( $Self->{Subaction} eq 'Deregister' || $Self->{Subaction} eq 'UpdateNow' ) {
             $Self->{Subaction} = 'OTRSIDValidate';
         }
     }
 
+    # get needed objects
+    my $ParamObject        = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $RegistrationObject = $Kernel::OM->Get('Kernel::System::Registration');
+
     # ------------------------------------------------------------ #
-    # Scheduler not running screen
+    # Daemon not running screen
     # ------------------------------------------------------------ #
     if (
         $Self->{Subaction} ne 'OTRSIDValidate'
-        && $Self->{RegistrationState} ne 'registered'
-        && !$Self->_SchedulerRunning()
+        && $RegistrationState ne 'registered'
+        && !$Self->_DaemonRunning()
         )
     {
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
-            Name => 'SchedulerNotRunning',
+        $LayoutObject->Block(
+            Name => 'DaemonNotRunning',
         );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -96,22 +104,22 @@ sub Run {
 
     elsif ( $Self->{Subaction} eq 'CheckOTRSID' ) {
 
-        my $OTRSID   = $Self->{ParamObject}->GetParam( Param => 'OTRSID' )   || '';
-        my $Password = $Self->{ParamObject}->GetParam( Param => 'Password' ) || '';
+        my $OTRSID   = $ParamObject->GetParam( Param => 'OTRSID' )   || '';
+        my $Password = $ParamObject->GetParam( Param => 'Password' ) || '';
 
-        my %Response = $Self->{RegistrationObject}->TokenGet(
+        my %Response = $RegistrationObject->TokenGet(
             OTRSID   => $OTRSID,
             Password => $Password,
         );
 
         # redirect to next page on success
         if ( $Response{Token} ) {
-            my $NextAction = $Self->{RegistrationState} ne 'registered' ? 'Register' : 'Deregister';
-            return $Self->{LayoutObject}->Redirect(
+            my $NextAction = $RegistrationState ne 'registered' ? 'Register' : 'Deregister';
+            return $LayoutObject->Redirect(
                 OP => "Action=AdminRegistration;Subaction=$NextAction;Token="
-                    . $Self->{LayoutObject}->LinkEncode( $Response{Token} )
+                    . $LayoutObject->LinkEncode( $Response{Token} )
                     . ';OTRSID='
-                    . $Self->{LayoutObject}->LinkEncode($OTRSID),
+                    . $LayoutObject->LinkEncode($OTRSID),
             );
         }
 
@@ -119,45 +127,45 @@ sub Run {
         my %Result = (
             Success => $Response{Success} ? 'OK' : 'False',
             Message => $Response{Reason} || '',
-            Token   => $Response{Token} || '',
+            Token   => $Response{Token}  || '',
         );
 
-        my $Output = $Self->{LayoutObject}->Header();
+        my $Output = $LayoutObject->Header();
         $Output .= $Response{Reason}
-            ? $Self->{LayoutObject}->Notify(
+            ? $LayoutObject->Notify(
             Priority => 'Error',
             Info     => $Response{Reason},
             )
             : '';
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Block(
+        $Output .= $LayoutObject->NavigationBar();
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'OTRSIDValidation',
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'OTRSIDValidationForm',
             Data => \%Param,
         );
 
-        my $Block = $Self->{RegistrationState} ne 'registered'
+        my $Block = $RegistrationState ne 'registered'
             ? 'OTRSIDRegistration'
             : 'OTRSIDDeregistration';
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => $Block,
         );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -167,70 +175,72 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'OTRSIDValidate' ) {
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Block(
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        my $EntitlementStatus = 'forbidden';
-        if ( $Self->{RegistrationState} eq 'registered' ) {
+        my $EntitlementStatus  = 'forbidden';
+        my $OTRSBusinessObject = $Kernel::OM->Get('Kernel::System::OTRSBusiness');
+
+        if ( $RegistrationState eq 'registered' ) {
 
             # Only call cloud service for a registered system
-            $EntitlementStatus = $Self->{OTRSBusinessObject}->OTRSBusinessEntitlementStatus(
+            $EntitlementStatus = $OTRSBusinessObject->OTRSBusinessEntitlementStatus(
                 CallCloudService => 1,
             );
         }
 
-        # users should not be able to de-register their system if they either have
+        # users should not be able to deregister their system if they either have
         # OTRS Business Solution installed or are entitled to use it (by having a valid contract).
         if (
-            $Self->{RegistrationState} eq 'registered'
-            && ( $Self->{OTRSBusinessObject}->OTRSBusinessIsInstalled() || $EntitlementStatus ne 'forbidden' )
+            $RegistrationState eq 'registered'
+            && ( $OTRSBusinessObject->OTRSBusinessIsInstalled() || $EntitlementStatus ne 'forbidden' )
             )
         {
 
-            $Self->{LayoutObject}->Block( Name => 'ActionList' );
-            $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+            $LayoutObject->Block( Name => 'ActionList' );
+            $LayoutObject->Block( Name => 'ActionOverview' );
 
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'OTRSIDDeregistrationNotPossible',
             );
         }
         else {
 
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'OTRSIDValidation',
                 Data => \%Param,
             );
 
-            # check if the scheduler is not running
-            if ( $Self->{RegistrationState} ne 'registered' && !$Self->_SchedulerRunning() ) {
+            # check if the daemon is not running
+            if ( $RegistrationState ne 'registered' && !$Self->_DaemonRunning() ) {
 
-                $Self->{LayoutObject}->Block(
-                    Name => 'OTRSIDValidationSchedulerNotRunning',
+                $LayoutObject->Block(
+                    Name => 'OTRSIDValidationDaemonNotRunning',
                 );
             }
             else {
 
-                $Self->{LayoutObject}->Block(
+                $LayoutObject->Block(
                     Name => 'OTRSIDValidationForm',
                     Data => \%Param,
                 );
             }
 
-            my $Block = $Self->{RegistrationState} ne 'registered' ? 'OTRSIDRegistration' : 'OTRSIDDeregistration';
-            $Self->{LayoutObject}->Block(
+            my $Block = $RegistrationState ne 'registered' ? 'OTRSIDRegistration' : 'OTRSIDDeregistration';
+            $LayoutObject->Block(
                 Name => $Block,
             );
         }
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -241,32 +251,38 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Register' ) {
 
         my %GetParam;
-        $GetParam{Token}  = $Self->{ParamObject}->GetParam( Param => 'Token' );
-        $GetParam{OTRSID} = $Self->{ParamObject}->GetParam( Param => 'OTRSID' );
+        $GetParam{Token}  = $ParamObject->GetParam( Param => 'Token' );
+        $GetParam{OTRSID} = $ParamObject->GetParam( Param => 'OTRSID' );
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Block(
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        $Param{SystemTypeOption} = $Self->{LayoutObject}->BuildSelection(
-            Data          => [qw( Production Test Training Development )],
+        $Param{SystemTypeOption} = $LayoutObject->BuildSelection(
+            Data => {
+                Production  => Translatable('Production'),
+                Test        => Translatable('Test'),
+                Training    => Translatable('Training'),
+                Development => Translatable('Development'),
+            },
             PossibleNone  => 1,
             Name          => 'Type',
             SelectedValue => $Param{SystemType},
-            Class         => 'Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
+            Class         => 'Modernize Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
         );
 
-        my %OSInfo = $Self->{EnvironmentObject}->OSInfoGet();
-        my %DBInfo = $Self->{EnvironmentObject}->DBInfoGet();
+        my $EnvironmentObject = $Kernel::OM->Get('Kernel::System::Environment');
+        my %OSInfo            = $EnvironmentObject->OSInfoGet();
+        my %DBInfo            = $EnvironmentObject->DBInfoGet();
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'Registration',
             Data => {
-                FQDN        => $Self->{ConfigObject}->Get('FQDN'),
-                OTRSVersion => $Self->{ConfigObject}->Get('Version'),
+                FQDN        => $ConfigObject->Get('FQDN'),
+                OTRSVersion => $ConfigObject->Get('Version'),
                 PerlVersion => sprintf( "%vd", $^V ),
                 %Param,
                 %GetParam,
@@ -275,11 +291,11 @@ sub Run {
             },
         );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -290,25 +306,25 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Deregister' ) {
 
         my %GetParam;
-        $GetParam{Token}  = $Self->{ParamObject}->GetParam( Param => 'Token' );
-        $GetParam{OTRSID} = $Self->{ParamObject}->GetParam( Param => 'OTRSID' );
+        $GetParam{Token}  = $ParamObject->GetParam( Param => 'Token' );
+        $GetParam{OTRSID} = $ParamObject->GetParam( Param => 'OTRSID' );
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Block(
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'Deregistration',
             Data => \%GetParam,
         );
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -319,11 +335,11 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         my ( %GetParam, %Errors );
         for my $Parameter (qw(SupportDataSending Type Description OTRSID Token)) {
-            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
+            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
         }
 
         # check needed data
@@ -336,7 +352,7 @@ sub Run {
         # if no errors occurred
         if ( !%Errors ) {
 
-            $Self->{RegistrationObject}->Register(
+            $RegistrationObject->Register(
                 Token              => $GetParam{Token},
                 OTRSID             => $GetParam{OTRSID},
                 SupportDataSending => $GetParam{SupportDataSending} || 'No',
@@ -344,15 +360,15 @@ sub Run {
                 Description        => $GetParam{Description},
             );
 
-            return $Self->{LayoutObject}->Redirect(
+            return $LayoutObject->Redirect(
                 OP => 'Action=AdminRegistration',
             );
         }
 
         # something has gone wrong
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $Output .= $LayoutObject->Notify( Priority => 'Error' );
 
         $Self->_Edit(
             Action => 'Add',
@@ -360,11 +376,11 @@ sub Run {
             %GetParam,
         );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -374,26 +390,31 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Edit' ) {
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Block(
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $LayoutObject->Block(
             Name => 'Overview',
             Data => \%Param,
         );
 
-        my %RegistrationData = $Self->{RegistrationObject}->RegistrationDataGet();
+        my %RegistrationData = $RegistrationObject->RegistrationDataGet();
 
         $Param{Description} //= $RegistrationData{Description};
 
-        $Param{SystemTypeOption} = $Self->{LayoutObject}->BuildSelection(
-            Data          => [qw( Production Test Training Development )],
+        $Param{SystemTypeOption} = $LayoutObject->BuildSelection(
+            Data => {
+                Production  => Translatable('Production'),
+                Test        => Translatable('Test'),
+                Training    => Translatable('Training'),
+                Development => Translatable('Development'),
+            },
             PossibleNone  => 1,
             Name          => 'Type',
             SelectedValue => $Param{Type} // $RegistrationData{Type},
-            Class         => 'Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
+            Class         => 'Modernize Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
         );
 
-        # fallback for support data sending switch
+        # fall-back for support data sending switch
         if ( !defined $RegistrationData{SupportDataSending} ) {
             $RegistrationData{SupportDataSending} = 'No';
         }
@@ -404,21 +425,21 @@ sub Run {
             $Param{SupportDataSendingChecked} = 'checked="checked"';
         }
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'Edit',
             Data => {
-                FQDN        => $Self->{ConfigObject}->Get('FQDN'),
-                OTRSVersion => $Self->{ConfigObject}->Get('Version'),
+                FQDN        => $ConfigObject->Get('FQDN'),
+                OTRSVersion => $ConfigObject->Get('Version'),
                 PerlVersion => sprintf( "%vd", $^V ),
                 %Param,
             },
         );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -429,13 +450,13 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'EditAction' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $RegistrationType   = $Self->{ParamObject}->GetParam( Param => 'Type' );
-        my $Description        = $Self->{ParamObject}->GetParam( Param => 'Description' );
-        my $SupportDataSending = $Self->{ParamObject}->GetParam( Param => 'SupportDataSending' ) || 'No';
+        my $RegistrationType   = $ParamObject->GetParam( Param => 'Type' );
+        my $Description        = $ParamObject->GetParam( Param => 'Description' );
+        my $SupportDataSending = $ParamObject->GetParam( Param => 'SupportDataSending' ) || 'No';
 
-        my %Result = $Self->{RegistrationObject}->RegistrationUpdateSend(
+        my %Result = $RegistrationObject->RegistrationUpdateSend(
             Type               => $RegistrationType,
             Description        => $Description,
             SupportDataSending => $SupportDataSending,
@@ -443,7 +464,7 @@ sub Run {
 
         # log change
         if ( $Result{Success} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message =>
                     "System Registration: User $Self->{UserID} changed Description: '$Description', Type: '$RegistrationType'.",
@@ -451,7 +472,7 @@ sub Run {
 
         }
 
-        return $Self->{LayoutObject}->Redirect(
+        return $LayoutObject->Redirect(
             OP => 'Action=AdminRegistration',
         );
     }
@@ -462,14 +483,14 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'DeregisterAction' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        $Self->{RegistrationObject}->Deregister(
-            OTRSID => $Self->{ParamObject}->GetParam( Param => 'OTRSID' ),
-            Token  => $Self->{ParamObject}->GetParam( Param => 'Token' ),
+        $RegistrationObject->Deregister(
+            OTRSID => $ParamObject->GetParam( Param => 'OTRSID' ),
+            Token  => $ParamObject->GetParam( Param => 'Token' ),
         );
 
-        return $Self->{LayoutObject}->Redirect(
+        return $LayoutObject->Redirect(
             OP => 'Action=Admin',
         );
     }
@@ -485,19 +506,19 @@ sub Run {
     # overview
     # ------------------------------------------------------------
     else {
-        my %RegistrationData = $Self->{RegistrationObject}->RegistrationDataGet();
+        my %RegistrationData = $RegistrationObject->RegistrationDataGet();
 
         $Self->_Overview(
             %RegistrationData,
         );
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Output .= $Self->{LayoutObject}->Output(
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminRegistration',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
 
         return $Output;
     }
@@ -506,20 +527,22 @@ sub Run {
 sub _Edit {
     my ( $Self, %Param ) = @_;
 
-    $Self->{LayoutObject}->Block(
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    $LayoutObject->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionOverview' );
 
     # shows header
     if ( $Param{Action} eq 'Change' ) {
-        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+        $LayoutObject->Block( Name => 'HeaderEdit' );
     }
     else {
-        $Self->{LayoutObject}->Block( Name => 'HeaderNew' );
+        $LayoutObject->Block( Name => 'HeaderNew' );
     }
 
     return 1;
@@ -528,17 +551,19 @@ sub _Edit {
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    $Self->{LayoutObject}->Block(
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    $LayoutObject->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionUpdate' );
-    $Self->{LayoutObject}->Block( Name => 'ActionSentDataOverview' );
-    $Self->{LayoutObject}->Block( Name => 'ActionDeregister' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionUpdate' );
+    $LayoutObject->Block( Name => 'ActionSentDataOverview' );
+    $LayoutObject->Block( Name => 'ActionDeregister' );
 
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'OverviewRegistered',
         Data => \%Param,
     );
@@ -549,36 +574,42 @@ sub _Overview {
 sub _SentDataOverview {
     my ( $Self, %Param ) = @_;
 
-    my $Output = $Self->{LayoutObject}->Header();
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    $Self->{LayoutObject}->Block(
+    my $Output = $LayoutObject->Header();
+    $Output .= $LayoutObject->NavigationBar();
+
+    $LayoutObject->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionOverview' );
 
-    my %RegistrationData = $Self->{RegistrationObject}->RegistrationDataGet();
+    my %RegistrationData = $Kernel::OM->Get('Kernel::System::Registration')->RegistrationDataGet();
 
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'SentDataOverview',
     );
 
-    if ( $Self->{RegistrationState} ne 'registered' ) {
-        $Self->{LayoutObject}->Block( Name => 'SentDataOverviewNoData' );
+    my $RegistrationState = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet(
+        Key => 'Registration::State',
+    ) || '';
+
+    if ( $RegistrationState ne 'registered' ) {
+        $LayoutObject->Block( Name => 'SentDataOverviewNoData' );
     }
     else {
         my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
         my %OSInfo       = $Kernel::OM->Get('Kernel::System::Environment')->OSInfoGet();
         my %System       = (
-            PerlVersion        => sprintf( "%vd", $^V ),
-            OSType             => $OSInfo{OS},
-            OSVersion          => $OSInfo{OSName},
-            OTRSVersion        => $ConfigObject->Get('Version'),
-            FQDN               => $ConfigObject->Get('FQDN'),
-            DatabaseVersion    => $Kernel::OM->Get('Kernel::System::DB')->Version(),
+            PerlVersion     => sprintf( "%vd", $^V ),
+            OSType          => $OSInfo{OS},
+            OSVersion       => $OSInfo{OSName},
+            OTRSVersion     => $ConfigObject->Get('Version'),
+            FQDN            => $ConfigObject->Get('FQDN'),
+            DatabaseVersion => $Kernel::OM->Get('Kernel::System::DB')->Version(),
             SupportDataSending => $Param{SupportDataSending} || $RegistrationData{SupportDataSending} || 'No',
         );
         my $RegistrationUpdateDataDump = $Kernel::OM->Get('Kernel::System::Main')->Dump( \%System );
@@ -589,7 +620,7 @@ sub _SentDataOverview {
             $SupportDataDump = $Kernel::OM->Get('Kernel::System::Main')->Dump( $SupportData{Result} );
         }
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'SentDataOverviewData',
             Data => {
                 RegistrationUpdate => $RegistrationUpdateDataDump,
@@ -598,31 +629,31 @@ sub _SentDataOverview {
         );
     }
 
-    $Output .= $Self->{LayoutObject}->Output(
+    $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminRegistration',
         Data         => \%Param,
     );
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
 
     return $Output;
 }
 
-sub _SchedulerRunning {
+sub _DaemonRunning {
     my ( $Self, %Param ) = @_;
 
-    # try to get scheduler PID
-    my %PID = $Self->{PIDObject}->PIDGet(
-        Name => 'otrs.Scheduler',
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    # get the NodeID from the SysConfig settings, this is used on High Availability systems.
+    my $NodeID = $ConfigObject->Get('NodeID') || 1;
+
+    # get running daemon cache
+    my $Running = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => 'DaemonRunning',
+        Key  => $NodeID,
     );
 
-    my $PIDUpdateTime = $Self->{ConfigObject}->Get('Scheduler::PIDUpdateTime') || 600;
-
-    # check if scheduler process is registered in the DB and if the update was not too long ago
-    if ( !%PID || ( time() - $PID{Changed} > 4 * $PIDUpdateTime ) ) {
-        return;
-    }
-
-    return 1;
+    return $Running;
 }
 
 1;
