@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -57,18 +57,20 @@ sub LinkObjectTableCreate {
     if ( $Param{ViewMode} =~ m{ \A Simple }xms ) {
 
         return $Self->LinkObjectTableCreateSimple(
-            LinkListWithData => $Param{LinkListWithData},
-            ViewMode         => $Param{ViewMode},
+            LinkListWithData               => $Param{LinkListWithData},
+            ViewMode                       => $Param{ViewMode},
+            AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
         );
     }
     else {
 
         return $Self->LinkObjectTableCreateComplex(
-            LinkListWithData => $Param{LinkListWithData},
-            ViewMode         => $Param{ViewMode},
-            AJAX             => $Param{AJAX},
-            SourceObject     => $Param{Object},
-            ObjectID         => $Param{Key},
+            LinkListWithData               => $Param{LinkListWithData},
+            ViewMode                       => $Param{ViewMode},
+            AJAX                           => $Param{AJAX},
+            SourceObject                   => $Param{Object},
+            ObjectID                       => $Param{Key},
+            AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
         );
     }
 }
@@ -312,6 +314,8 @@ sub LinkObjectTableCreateComplex {
     my $OriginalAction = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => 'OriginalAction' )
         || $Self->{Action};
 
+    my %ColumnsTranslations = ();
+
     BLOCK:
     for my $Block (@OutputData) {
 
@@ -359,16 +363,9 @@ sub LinkObjectTableCreateComplex {
 
             # Add translations for the allocation lists for regular columns.
             for my $Column ( @{ $Block->{AllColumns} } ) {
-                $LayoutObject->Block(
-                    Name => 'ColumnTranslation',
-                    Data => {
-                        ColumnName      => $Column->{ColumnName},
-                        ColumnTranslate => $Column->{ColumnTranslate},
-                    },
-                );
-                $LayoutObject->Block(
-                    Name => 'ColumnTranslationSeparator',
-                );
+                my $Name = $Column->{ColumnName};
+                $ColumnsTranslations{"Column${ Name }"}
+                    = $Kernel::OM->Get('Kernel::Language')->Translate( $Column->{ColumnTranslate}, );
             }
 
             $LayoutObject->Block(
@@ -383,13 +380,14 @@ sub LinkObjectTableCreateComplex {
                 Name => $Preferences{Name} . 'PreferencesItem' . $Preferences{Block},
                 Data => {
                     %Preferences,
-                    NameForm          => $Block->{Blockname},
-                    NamePref          => $Preferences{Name},
-                    Name              => $Block->{Blockname},
-                    SourceObject      => $Param{SourceObject},
-                    DestinationObject => $Block->{Blockname},
-                    OriginalAction    => $OriginalAction,
-                    SourceObjectData  => $SourceObjectData,
+                    NameForm                       => $Block->{Blockname},
+                    NamePref                       => $Preferences{Name},
+                    Name                           => $Block->{Blockname},
+                    SourceObject                   => $Param{SourceObject},
+                    DestinationObject              => $Block->{Blockname},
+                    OriginalAction                 => $OriginalAction,
+                    SourceObjectData               => $SourceObjectData,
+                    AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
                 },
             );
         }
@@ -488,6 +486,13 @@ sub LinkObjectTableCreateComplex {
         $BlockCounter++;
     }
 
+    $LayoutObject->Block(
+        Name => 'ColumnTranslation',
+        Data => {
+            Translations => \%ColumnsTranslations,
+        },
+    );
+
     return $LayoutObject->Output(
         TemplateFile   => 'LinkObject',
         KeepScriptTags => $Param{AJAX},
