@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -1458,6 +1458,19 @@ sub Run {
                     next TICKETCOLUMN;
                 }
 
+                if ( $TicketColumn eq 'CreatedBy' ) {
+
+                    my %TicketCreatedByInfo = $UserObject->GetUserData(
+                        UserID => $Article{CreatedBy},
+                    );
+
+                    $LayoutObject->Block(
+                        Name => 'RecordTicketCreatedBy',
+                        Data => \%TicketCreatedByInfo,
+                    );
+                    next TICKETCOLUMN;
+                }
+
                 # escalation column
                 my %EscalationData;
                 if ( $TicketColumn eq 'EscalationTime' ) {
@@ -1490,13 +1503,22 @@ sub Run {
                 my $CSSClass  = '';
                 if ( $TicketColumn eq 'EscalationSolutionTime' ) {
                     $BlockType = 'Escalation';
+
+                    # Article SolutionTime is taken into consideration only when there is EscalationSolutionTime.
+                    # See bug#12912 (https://bugs.otrs.org/show_bug.cgi?id=12912).
+                    my $SolutionTime = 0;
+                    if ( $Article{EscalationSolutionTime} ) {
+                        $SolutionTime = $Article{SolutionTime};
+
+                        if ( $SolutionTime < 60 * 60 * 1 ) {
+                            $CSSClass = 'Warning';
+                        }
+                    }
+
                     $DataValue = $LayoutObject->CustomerAgeInHours(
-                        Age => $Article{SolutionTime} || 0,
+                        Age   => $SolutionTime,
                         Space => ' ',
                     );
-                    if ( defined $Article{SolutionTime} && $Article{SolutionTime} < 60 * 60 * 1 ) {
-                        $CSSClass = 'Warning';
-                    }
                 }
                 elsif ( $TicketColumn eq 'EscalationResponseTime' ) {
                     $BlockType = 'Escalation';
