@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -112,6 +112,9 @@ sub Crypt {
         }
     }
 
+    # Quote the key parameter before passing it to the shell.
+    my $QuotedKey = $Self->_QuoteShellArgument( $Param{Key} );
+
     $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput( \$Param{Message} );
 
     # get temp file object
@@ -123,7 +126,7 @@ sub Crypt {
 
     my ( $FHCrypt, $FilenameCrypt ) = $FileTempObject->TempFile();
     close $FHCrypt;
-    my $GPGOptions = "--always-trust --yes --encrypt --armor -o $FilenameCrypt -r $Param{Key} $Filename";
+    my $GPGOptions = "--always-trust --yes --encrypt --armor -o $FilenameCrypt -r $QuotedKey $Filename";
     my $LogMessage = qx{$Self->{GPGBin} $GPGOptions 2>&1};
 
     # get crypted content
@@ -242,6 +245,9 @@ sub Sign {
     print $FHPhrase $Pw;
     close $FHPhrase;
 
+    # Quote the key parameter before passing it to the shell.
+    my $QuotedKey = $Self->_QuoteShellArgument( $Param{Key} );
+
     my $Quiet = '';
 
     # GnuPG 2.1 (and higher) may send info messages about used default keys to STDERR, which leads to problems.
@@ -253,7 +259,7 @@ sub Sign {
         $Quiet = '--quiet --batch --pinentry-mode=loopback';
     }
 
-    my $GPGOptions = qq{$Quiet --passphrase-fd 0 -o $FileSign --default-key $Param{Key} $SigType $Filename};
+    my $GPGOptions = qq{$Quiet --passphrase-fd 0 -o $FileSign --default-key $QuotedKey $SigType $Filename};
     my $LogMessage = qx{$Self->{GPGBin} $GPGOptions < $FilePhrase 2>&1};
 
     # error
@@ -649,7 +655,7 @@ returns an array with search result (private keys)
 sub PrivateKeySearch {
     my ( $Self, %Param ) = @_;
 
-    my $Search         = $Param{Search} || '';
+    my $Search         = $Self->_QuoteShellArgument( $Param{Search} ) || '';
     my $GPGOptions     = "--list-secret-keys --with-fingerprint --with-colons $Search";
     my @GPGOutputLines = qx{$Self->{GPGBin} $GPGOptions 2>&1};
 
@@ -669,7 +675,7 @@ returns an array with search result (public keys)
 sub PublicKeySearch {
     my ( $Self, %Param ) = @_;
 
-    my $Search         = $Param{Search} || '';
+    my $Search         = $Self->_QuoteShellArgument( $Param{Search} ) || '';
     my $GPGOptions     = "--list-keys --with-fingerprint --with-colons $Search";
     my @GPGOutputLines = qx{$Self->{GPGBin} $GPGOptions 2>&1};
 
@@ -689,8 +695,8 @@ returns public key in ascii
 sub PublicKeyGet {
     my ( $Self, %Param ) = @_;
 
-    my $Key = quotemeta( $Param{Key} || '' );
-    my $LogMessage = qx{$Self->{GPGBin} --export --armor $Key 2>&1};
+    my $QuotedKey = $Self->_QuoteShellArgument( $Param{Key} ) || '';
+    my $LogMessage = qx{$Self->{GPGBin} --export --armor $QuotedKey 2>&1};
     my $PublicKey;
     if ( $LogMessage =~ /nothing exported/i ) {
         $LogMessage =~ s/\n//g;
@@ -730,8 +736,6 @@ returns secret key in ascii
 sub SecretKeyGet {
     my ( $Self, %Param ) = @_;
 
-    my $Key = quotemeta( $Param{Key} || '' );
-
     my $LogMessage = '';
 
     # GnuPG 2.1 (and higher) asks via pinentry for the key passphrase. We suppress that behavior by passing the phrase
@@ -742,7 +746,8 @@ sub SecretKeyGet {
         )
     {
         my %PasswordHash = %{ $Kernel::OM->Get('Kernel::Config')->Get('PGP::Key::Password') };
-        my $Password = $PasswordHash{$Key} || '';
+        my $Key          = quotemeta( $Param{Key} || '' );
+        my $Password     = $PasswordHash{$Key} || '';
 
         my ( $FH, $Filename ) = $Kernel::OM->Get('Kernel::System::FileTemp')->TempFile();
         print $FH $Password;
@@ -754,7 +759,8 @@ sub SecretKeyGet {
 
     # GnuPG 2.0 (and lower)
     else {
-        $LogMessage = qx{$Self->{GPGBin} --export-secret-keys --armor $Key 2>&1};
+        my $QuotedKey = $Self->_QuoteShellArgument( $Param{Key} ) || '';
+        $LogMessage = qx{$Self->{GPGBin} --export-secret-keys --armor $QuotedKey 2>&1};
     }
 
     my $SecretKey = '';
@@ -803,9 +809,9 @@ sub PublicKeyDelete {
         return;
     }
 
-    my $Key        = quotemeta( $Param{Key} || '' );
+    my $QuotedKey  = $Self->_QuoteShellArgument( $Param{Key} ) || '';
     my $GPGOptions = '--status-fd 1';
-    my $Message    = qx{$Self->{GPGBin} $GPGOptions --delete-key $Key 2>&1};
+    my $Message    = qx{$Self->{GPGBin} $GPGOptions --delete-key $QuotedKey 2>&1};
 
     my %LogMessage = $Self->_HandleLog( LogString => $Message );
 
@@ -982,6 +988,9 @@ sub _DecryptPart {
     print $FHPhrase $Param{Password};
     close $FHPhrase;
 
+    # Quote the filename parameter before passing it to the shell.
+    my $QuotedFilename = $Self->_QuoteShellArgument( $Param{Filename} );
+
     my $LogMessage = '';
 
     # GnuPG 2.1 (and higher)
@@ -991,13 +1000,13 @@ sub _DecryptPart {
         )
     {
         my $GPGOptions
-            = qq{--batch --pinentry-mode=loopback --passphrase-fd 0 --armor -o $FileDecrypt --decrypt $Param{Filename}};
+            = qq{--batch --pinentry-mode=loopback --passphrase-fd 0 --armor -o $FileDecrypt --decrypt $QuotedFilename};
         $LogMessage = qx{$Self->{GPGBin} $GPGOptions < $FilePhrase 2>&1};
     }
 
     # GnuPG 2.0 (and lower)
     else {
-        my $GPGOptions = qq{--batch --passphrase-fd 0 --yes --decrypt -o $FileDecrypt $Param{Filename}};
+        my $GPGOptions = qq{--batch --passphrase-fd 0 --yes --decrypt -o $FileDecrypt $QuotedFilename};
         $LogMessage = qx{$Self->{GPGBin} $GPGOptions <$FilePhrase 2>&1};
     }
 
@@ -1230,6 +1239,9 @@ sub _CryptedWithKey {
         return;
     }
 
+    # Quote the file parameter before passing it to the shell.
+    my $QuotedFile = $Self->_QuoteShellArgument( $Param{File} );
+
     # This is a bit tricky: all we actually want is the list of keys that this message has been
     # encrypted for, but gpg does not seem to offer a way to just get these.
     # So we simply try to decrypt with an incorrect passphrase, which of course fails, but still
@@ -1238,7 +1250,7 @@ sub _CryptedWithKey {
     my ( $FHPhrase, $FilePhrase ) = $Kernel::OM->Get('Kernel::System::FileTemp')->TempFile();
     print $FHPhrase '_no_this_is_not_the_@correct@_passphrase_';
     close $FHPhrase;
-    my $GPGOptions     = qq{--batch --passphrase-fd 0 --always-trust --yes --decrypt $Param{File}};
+    my $GPGOptions     = qq{--batch --passphrase-fd 0 --always-trust --yes --decrypt $QuotedFile};
     my @GPGOutputLines = qx{$Self->{GPGBin} $GPGOptions <$FilePhrase 2>&1};
 
     my @Keys;
@@ -1255,6 +1267,39 @@ sub _CryptedWithKey {
     return @Keys;
 }
 
+=item _QuoteShellArgument()
+
+Quote passed string to be safe to use as a shell argument.
+
+    my $Result = $Self->_QuoteShellArgument(
+        "Safe string for 'shell arguments'."   # string to quote
+    );
+
+Returns quoted string if supplied or undef otherwise:
+
+    $Result = <<'EOS';
+'Safe string for '"'"'shell arguments'"'"'.'
+EOS
+
+=cut
+
+sub _QuoteShellArgument {
+    my ( $Self, $String ) = @_;
+
+    # Only continue with quoting if we received a valid string.
+    if ( IsStringWithData($String) ) {
+
+        # Encase any single quotes in double quotes, and glue them together with single quotes.
+        #   Please see https://stackoverflow.com/a/1250279 for more information.
+        $String =~ s/'/'"'"'/g;
+
+        # Enclose the string in single quotes.
+        return "'$String'";
+    }
+
+    return;
+}
+
 1;
 
 =end Internal:
