@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -318,7 +318,7 @@ sub CustomerUserDataGet {
 
         next SOURCE if !$Self->{"CustomerUser$Count"};
 
-        my %Customer = $Self->{"CustomerUser$Count"}->CustomerUserDataGet( %Param, );
+        my %Customer = $Self->{"CustomerUser$Count"}->CustomerUserDataGet(%Param);
         next SOURCE if !%Customer;
 
         # add preferences defaults
