@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,6 +16,7 @@ use Digest::SHA;
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::Language',
     'Kernel::System::Cache',
     'Kernel::System::CheckItem',
     'Kernel::System::DB',
@@ -235,6 +236,11 @@ sub CustomerSearch {
 
         my $Search = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{Search} );
 
+        if ( $Param{CustomerUserOnly} ) {
+            @{ $Self->{CustomerUserMap}->{CustomerUserSearchFields} }
+                = grep { $_ ne 'customer_id' } @{ $Self->{CustomerUserMap}->{CustomerUserSearchFields} };
+        }
+
         my %QueryCondition = $Self->{DBObject}->QueryCondition(
             Key           => $Self->{CustomerUserMap}->{CustomerUserSearchFields},
             Value         => $Search,
@@ -722,7 +728,8 @@ sub CustomerUserAdd {
         if (%Result) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => 'Email already exists!',
+                Message  => $Kernel::OM->Get('Kernel::Language')
+                    ->Translate('This email address is already in use for another customer user.'),
             );
             return;
         }
@@ -735,6 +742,7 @@ sub CustomerUserAdd {
     if (
         $Param{UserEmail}
         && !$CheckItemObject->CheckEmail( Address => $Param{UserEmail} )
+        && grep { $_ eq $Param{ValidID} } $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet()
         )
     {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -862,6 +870,7 @@ sub CustomerUserUpdate {
     if (
         $Param{UserEmail}
         && !$CheckItemObject->CheckEmail( Address => $Param{UserEmail} )
+        && grep { $_ eq $Param{ValidID} } $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet()
         )
     {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -889,7 +898,8 @@ sub CustomerUserUpdate {
         if (%Result) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => 'Email already exists!',
+                Message  => $Kernel::OM->Get('Kernel::Language')
+                    ->Translate('This email address is already in use for another customer user.'),
             );
             return;
         }
@@ -1243,6 +1253,10 @@ sub _CustomerUserCacheClear {
         Type => $Self->{CacheType} . '_CustomerSearch',
     );
 
+    $Self->{CacheObject}->CleanUp(
+        Type => 'CustomerGroup',
+    );
+
     for my $Function (qw(CustomerUserList)) {
         for my $Valid ( 0 .. 1 ) {
             $Self->{CacheObject}->Delete(
