@@ -219,6 +219,9 @@ sub TableCreate {
         # auto increment
         if ( $Tag->{AutoIncrement} && $Tag->{AutoIncrement} =~ /^true$/i ) {
             $SQL = "    $Tag->{Name} serial";
+            if ( $Tag->{Type} =~ /^bigint$/i ) {
+                $SQL = "    $Tag->{Name} bigserial";
+            }
         }
 
         # normal data type
@@ -343,6 +346,8 @@ sub TableAlter {
     my $ReferenceName = '';
     my @Reference     = ();
     my $Table         = '';
+
+    TAG:
     for my $Tag (@Param) {
 
         if ( $Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start' ) {
@@ -366,6 +371,17 @@ sub TableAlter {
             # Type translation
             $Tag = $Self->_TypeTranslation($Tag);
 
+            # auto increment
+            if ( $Tag->{AutoIncrement} && $Tag->{AutoIncrement} =~ /^true$/i ) {
+
+                my $PseudoType = 'serial';
+                if ( $Tag->{Type} =~ /^bigint$/i ) {
+                    $PseudoType = 'bigserial';
+                }
+                push @SQL, $SQLStart . " ADD $Tag->{Name} $PseudoType NOT NULL";
+                next TAG;
+            }
+
             # normal data type
             push @SQL, $SQLStart . " ADD $Tag->{Name} $Tag->{Type} NULL";
 
@@ -409,6 +425,9 @@ sub TableAlter {
             }
             push @SQL, $SQLStart . " ALTER $Tag->{NameNew} TYPE $Tag->{Type}";
 
+            # if there is an AutoIncrement column no other changes are needed
+            next TAG if $Tag->{AutoIncrement} && $Tag->{AutoIncrement} =~ /^true$/i;
+
             # remove possible default
             push @SQL, "ALTER TABLE $Table ALTER $Tag->{NameNew} DROP DEFAULT";
 
@@ -740,12 +759,6 @@ sub _TypeTranslation {
     }
 
     # performance option
-    elsif ( $Tag->{Type} =~ /^smallint$/i ) {
-        $Tag->{Type} = 'INTEGER';
-    }
-    elsif ( $Tag->{Type} =~ /^bigint$/i ) {
-        $Tag->{Type} = 'INTEGER';
-    }
     elsif ( $Tag->{Type} =~ /^longblob$/i ) {
         $Tag->{Type} = 'TEXT';
     }
