@@ -634,7 +634,7 @@ sub DynamicFieldList {
             next FIELDNAME if !IsHashRefWithData($FieldConfig);
             next FIELDNAME if !$FieldConfig->{ID};
 
-            $AllowedFieldIDs{ $FieldConfig->{ID} } = 1;
+            $AllowedFieldIDs{ $FieldConfig->{ID} } = 1,
         }
     }
 
@@ -710,7 +710,7 @@ sub DynamicFieldList {
             for my $FieldID ( sort keys %{$Cache} ) {
                 next FIELDID if !$AllowedFieldIDs{$FieldID};
 
-                $FilteredData->{$FieldID} = $Cache->{$FieldID};
+                $FilteredData->{$FieldID} = $Cache->{$FieldID}
             }
         }
 
@@ -961,7 +961,7 @@ sub DynamicFieldListGet {
             next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
             next DYNAMICFIELD if !$Param{FieldFilter}->{ $DynamicFieldConfig->{Name} };
 
-            push @{$FilteredData}, $DynamicFieldConfig;
+            push @{$FilteredData}, $DynamicFieldConfig,
         }
 
         # return filtered data from cache
@@ -1059,7 +1059,7 @@ sub DynamicFieldListGet {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
         next DYNAMICFIELD if !$Param{FieldFilter}->{ $DynamicFieldConfig->{Name} };
 
-        push @{$FilteredData}, $DynamicFieldConfig;
+        push @{$FilteredData}, $DynamicFieldConfig,
     }
 
     # return filtered data from DB
@@ -1166,7 +1166,7 @@ sub DynamicFieldOrderCheck {
 
         # when finding a field with wrong order, set OrderError flag and exit loop
         $OrderError = 1;
-        last DYNAMICFIELD;
+        last DYNAMICFIELD
     }
 
     return if $OrderError;
