@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 use base qw(Kernel::System::DynamicField::Driver::Base);
 
@@ -398,7 +399,7 @@ sub EditFieldValueValidate {
         return {
             ServerError  => 1,
             ErrorMessage => 'Invalid Date!'
-        };
+            }
     }
 
     my $ServerError;
@@ -474,12 +475,14 @@ sub DisplayValueRender {
     my $Title = $Value;
 
     # set field link form config
-    my $Link = $Param{DynamicFieldConfig}->{Config}->{Link} || '';
+    my $Link        = $Param{DynamicFieldConfig}->{Config}->{Link}        || '';
+    my $LinkPreview = $Param{DynamicFieldConfig}->{Config}->{LinkPreview} || '';
 
     my $Data = {
-        Value => $Value,
-        Title => $Title,
-        Link  => $Link,
+        Value       => $Value,
+        Title       => $Title,
+        Link        => $Link,
+        LinkPreview => $LinkPreview,
     };
 
     return $Data;
@@ -603,15 +606,15 @@ EOF
 
         $HTMLString .= $Param{LayoutObject}->BuildSelection(
             Data => {
-                'Before' => 'more than ... ago',
-                'Last'   => 'within the last ...',
-                'Next'   => 'within the next ...',
-                'After'  => 'in more than ...',
+                'Before' => Translatable('more than ... ago'),
+                'Last'   => Translatable('within the last ...'),
+                'Next'   => Translatable('within the next ...'),
+                'After'  => Translatable('in more than ...'),
             },
             Sort           => 'IndividualKey',
             SortIndividual => [ 'Before', 'Last', 'Next', 'After' ],
             Name           => $FieldName . 'Start',
-            SelectedID     => $Value->{Start}->{ $FieldName . 'Start' } || 'Last',
+            SelectedID => $Value->{Start}->{ $FieldName . 'Start' } || 'Last',
         );
         $HTMLString .= ' ' . $Param{LayoutObject}->BuildSelection(
             Data       => [ 1 .. 59 ],
@@ -620,12 +623,12 @@ EOF
         );
         $HTMLString .= ' ' . $Param{LayoutObject}->BuildSelection(
             Data => {
-                minute => 'minute(s)',
-                hour   => 'hour(s)',
-                day    => 'day(s)',
-                week   => 'week(s)',
-                month  => 'month(s)',
-                year   => 'year(s)',
+                minute => Translatable('minute(s)'),
+                hour   => Translatable('hour(s)'),
+                day    => Translatable('day(s)'),
+                week   => Translatable('week(s)'),
+                month  => Translatable('month(s)'),
+                year   => Translatable('year(s)'),
             },
             Name       => $FieldName . 'Format',
             SelectedID => $Value->{Format}->{ $FieldName . 'Format' } || 'day',
@@ -633,7 +636,7 @@ EOF
 
         my $AdditionalText;
         if ( $Param{UseLabelHints} ) {
-            $AdditionalText = 'before/after';
+            $AdditionalText = Translatable('before/after');
         }
 
         # call EditLabelRender on the common backend
@@ -670,6 +673,7 @@ EOF
         Validate             => 1,
         %{ $Value->{ValueStart} },
         %YearsPeriodRange,
+        OverrideTimeZone => 1,
     );
 
     # to put a line break between the two search dates
@@ -693,11 +697,12 @@ EOF
         Validate             => 1,
         %{ $Value->{ValueStop} },
         %YearsPeriodRange,
+        OverrideTimeZone => 1,
     );
 
     my $AdditionalText;
     if ( $Param{UseLabelHints} ) {
-        $AdditionalText = 'between';
+        $AdditionalText = Translatable('between');
     }
 
     # call EditLabelRender on the common Driver
@@ -764,7 +769,7 @@ sub SearchFieldValueGet {
 
         $DynamicFieldValues{$Prefix} = 1;
 
-        # check if return value structure is nedded
+        # check if return value structure is needed
         if ( defined $Param{ReturnProfileStructure} && $Param{ReturnProfileStructure} eq '1' ) {
             return \%DynamicFieldValues;
         }
@@ -954,13 +959,13 @@ sub SearchFieldParameterBuild {
             # get time object
             my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
 
-            # get the current time in epoch seconds and as timestamp
+            # get the current time in epoch seconds and as time-stamp
             my $Now          = $TimeObject->SystemTime();
             my $NowTimeStamp = $TimeObject->SystemTime2TimeStamp(
                 SystemTime => $Now,
             );
 
-            # calculate diff time seconds
+            # calculate difference time seconds
             my $DiffTimeSeconds = $DiffTimeMinutes * 60;
 
             my $DisplayValue = '';
@@ -968,7 +973,7 @@ sub SearchFieldParameterBuild {
             # define to search before or after that time stamp
             if ( $Start eq 'Before' ) {
 
-                # we must subtract the diff because it is in the past
+                # we must subtract the difference because it is in the past
                 my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
                     SystemTime => $Now - $DiffTimeSeconds,
                 );
@@ -981,7 +986,7 @@ sub SearchFieldParameterBuild {
             }
             elsif ( $Start eq 'Last' ) {
 
-                # we must subtract the diff because it is in the past
+                # we must subtract the differences because it is in the past
                 my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
                     SystemTime => $Now - $DiffTimeSeconds,
                 );
@@ -995,7 +1000,7 @@ sub SearchFieldParameterBuild {
             }
             elsif ( $Start eq 'Next' ) {
 
-                # we must add the diff because it is in the future
+                # we must add the difference because it is in the future
                 my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
                     SystemTime => $Now + $DiffTimeSeconds,
                 );
@@ -1009,7 +1014,7 @@ sub SearchFieldParameterBuild {
             }
             elsif ( $Start eq 'After' ) {
 
-                # we must add the diff because it is in the future
+                # we must add the difference because it is in the future
                 my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
                     SystemTime => $Now + $DiffTimeSeconds,
                 );
@@ -1112,18 +1117,18 @@ sub TemplateValueTypeGet {
     if ( $Param{FieldType} eq 'Edit' ) {
         return {
             $FieldName => $EditValueType,
-        };
+            }
     }
     elsif ( $Param{FieldType} eq 'Search' ) {
         return {
             'Search_' . $FieldName => $SearchValueType,
-        };
+            }
     }
     else {
         return {
             $FieldName             => $EditValueType,
             'Search_' . $FieldName => $SearchValueType,
-        };
+            }
     }
 }
 
