@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -97,18 +97,35 @@ sub new {
 
     return $Self if !eval "require IPC::SysV";    ## no critic
 
-    # create the IPC options
-    $Self->{IPC}     = 1;
-    $Self->{IPCKey}  = '444423' . $SystemID;
+    # Setup IPC for shared access to the last log entries.
+    $Self->{IPCKey} = '444423' . $SystemID;       # This name is used to identify the shared memory segment.
     $Self->{IPCSize} = $ConfigObject->Get('LogSystemCacheSize') || 32 * 1024;
 
-    # init session data mem
-    if ( !eval { $Self->{Key} = shmget( $Self->{IPCKey}, $Self->{IPCSize}, oct(1777) ) } ) {
-        $Self->{Key} = shmget( $Self->{IPCKey}, 1, oct(1777) );
-        $Self->CleanUp();
-        $Self->{Key} = shmget( $Self->{IPCKey}, $Self->{IPCSize}, oct(1777) );
+    # Create/access shared memory segment.
+    if ( !eval { $Self->{IPCSHMKey} = shmget( $Self->{IPCKey}, $Self->{IPCSize}, oct(1777) ) } ) {
+
+        # If direct creation fails, try more gently, allocate a small segment first and the reset/resize it.
+        $Self->{IPCSHMKey} = shmget( $Self->{IPCKey}, 1, oct(1777) );
+        if ( !shmctl( $Self->{IPCSHMKey}, 0, 0 ) ) {
+            $Self->Log(
+                Priority => 'error',
+                Message  => "Can't remove shm for log: $!",
+            );
+
+            # Continue without IPC.
+            return $Self;
+        }
+
+        # Re-initialize SHM segment.
+        $Self->{IPCSHMKey} = shmget( $Self->{IPCKey}, $Self->{IPCSize}, oct(1777) );
     }
 
+    # Continue without IPC.
+    return $Self if !$Self->{IPCSHMKey};
+
+    # Only flag IPC as active if everything worked well.
+    $Self->{IPC} = 1;
+
     return $Self;
 }
 
@@ -134,7 +151,7 @@ Normal but significant condition; events that are unusual but not error conditio
 
 =item error
 
-Error conditions. Non-urgent failures, should be relayed to developers or admins, each item must be resolved.
+Error conditions. Non-urgent failures, should be relayed to developers or administrators, each item must be resolved.
 
 =back
 
@@ -242,7 +259,7 @@ sub Log {
         my $Data   = localtime() . ";;$Priority;;$Self->{LogPrefix};;$Message\n";    ## no critic
         my $String = $Self->GetLog();
 
-        shmwrite( $Self->{Key}, $Data . $String, 0, $Self->{IPCSize} ) || die $!;
+        shmwrite( $Self->{IPCSHMKey}, $Data . $String, 0, $Self->{IPCSize} ) || die $!;
     }
 
     return 1;
@@ -278,7 +295,7 @@ sub GetLog {
 
     my $String = '';
     if ( $Self->{IPC} ) {
-        shmread( $Self->{Key}, $String, 0, $Self->{IPCSize} ) || die "$!";
+        shmread( $Self->{IPCSHMKey}, $String, 0, $Self->{IPCSize} ) || die "$!";
     }
 
     # Remove \0 bytes that shmwrite adds for padding.
@@ -303,17 +320,7 @@ sub CleanUp {
 
     return 1 if !$Self->{IPC};
 
-    # remove the shm
-    if ( !shmctl( $Self->{Key}, 0, 0 ) ) {
-        $Self->Log(
-            Priority => 'notice',
-            Message  => "Can't remove shm for log: $!",
-        );
-        return;
-    }
-
-    # Re-initialize SHM segment.
-    $Self->{Key} = shmget( $Self->{IPCKey}, $Self->{IPCSize}, oct(1777) );
+    shmwrite( $Self->{IPCSHMKey}, '', 0, $Self->{IPCSize} ) || die $!;
 
     return 1;
 }
