@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Main;
@@ -18,6 +18,7 @@ use File::stat;
 use Unicode::Normalize;
 use List::Util qw();
 use Storable;
+use Fcntl qw(:flock);
 
 our @ObjectDependencies = (
     'Kernel::System::Encode',
@@ -227,13 +228,15 @@ sub FilenameCleanUp {
         return;
     }
 
-    if ( $Param{Type} && $Param{Type} =~ /^md5/i ) {
+    my $Type = lc( $Param{Type} || 'local' );
+
+    if ( $Type eq 'md5' ) {
         $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput( \$Param{Filename} );
         $Param{Filename} = md5_hex( $Param{Filename} );
     }
 
     # replace invalid token for attachment file names
-    elsif ( $Param{Type} && $Param{Type} =~ /^attachment/i ) {
+    elsif ( $Type eq 'attachment' ) {
 
         # replace invalid token like < > ? " : ; | \ / or *
         $Param{Filename} =~ s/[ <>\?":\\\*\|\/;\[\]]/_/g;
@@ -355,7 +358,7 @@ sub FileRead {
     }
 
     # lock file (Shared Lock)
-    if ( !flock $FH, 1 ) {
+    if ( !flock $FH, LOCK_SH ) {
         if ( !$Param{DisableWarnings} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
@@ -411,8 +414,8 @@ to write data to file system
         Permission => '644',     # optional - unix file permissions
     );
 
-Platform note: MacOS (HFS+) stores filenames as Unicode NFD internally,
-and DirectoryRead() will also report them as NFD.
+Platform note: MacOS (HFS+) stores filenames as Unicode C<NFD> internally,
+and DirectoryRead() will also report them as C<NFD>.
 
 =cut
 
@@ -467,7 +470,7 @@ sub FileWrite {
     }
 
     # lock file (Exclusive Lock)
-    if ( !flock $FH, 2 ) {
+    if ( !flock $FH, LOCK_EX ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't lock '$Param{Location}': $!",
@@ -643,7 +646,7 @@ sub FileGetMTime {
 
 =item MD5sum()
 
-get a md5 sum of a file or a string
+get an C<MD5> sum of a file or a string
 
     my $MD5Sum = $MainObject->MD5sum(
         Filename => '/path/to/me_to_alal.xml',
@@ -845,8 +848,8 @@ does not have to exist:
         Silent    => 1,     # will not log errors if the directory does not exist
     );
 
-Platform note: MacOS (HFS+) stores filenames as Unicode NFD internally,
-and DirectoryRead() will also report them as NFD.
+Platform note: MacOS (HFS+) stores filenames as Unicode C<NFD> internally,
+and DirectoryRead() will also report them as C<NFD>.
 
 =cut
 
@@ -964,7 +967,7 @@ sub DirectoryRead {
 
 =item GenerateRandomString()
 
-generate a random string of defined lenght, and of a defined alphabet.
+generate a random string of defined length, and of a defined alphabet.
 defaults to a length of 16 and alphanumerics ( 0..9, A-Z and a-z).
 
     my $String = $MainObject->GenerateRandomString();
@@ -1118,10 +1121,10 @@ sub _Dump {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
