@@ -16,7 +16,7 @@ use Kernel::System::VariableCheck qw(:all);
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Cache',
-    'Kernel::System::CloudService',
+    'Kernel::System::CloudService::Backend::Run',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
     'Kernel::System::Log',
@@ -32,6 +32,9 @@ my $NoConnectWarningPeriod = 60 * 60 * 24 * 5;    # 5 days
 # If we cannot connect to cloud.otrs.com for more than the second period, show an error.
 my $NoConnectErrorPeriod = 60 * 60 * 24 * 15;     # 15 days
 
+# If we cannot connect to cloud.otrs.com for more than the second period, block the system.
+my $NoConnectBlockPeriod = 60 * 60 * 24 * 25;     # 25 days
+
 # If the contract is about to expire in less than this time, show a hint
 my $ContractExpiryWarningPeriod = 60 * 60 * 24 * 28;    # 28 days
 
@@ -67,13 +70,19 @@ sub new {
 
     #$Self->{APIVersion} = 1;
 
+    # Get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # Get OTRSBusiness::ReleaseChannel from SysConfig (Stable = 1, Development = 0)
-    $Self->{OnlyStable} = $Kernel::OM->Get('Kernel::Config')->Get('OTRSBusiness::ReleaseChannel') // 1;
+    $Self->{OnlyStable} = $ConfigObject->Get('OTRSBusiness::ReleaseChannel') // 1;
 
     # Set cache params
     $Self->{CacheType} = 'OTRSBusiness';
     $Self->{CacheTTL}  = 60 * 60 * 24 * 30;    # 30 days
 
+    # Check if cloud services are disabled
+    $Self->{CloudServicesDisabled} = $ConfigObject->Get('CloudServices::Disabled') || 0;
+
     return $Self;
 }
 
@@ -116,14 +125,16 @@ sub OTRSBusinessIsInstalled {
 
 =item OTRSBusinessIsAvailable()
 
-checks with cloud.otrs.com if OTRSBusiness is available for the current framework.
+checks with C<cloud.otrs.com> if OTRSBusiness is available for the current framework.
 
 =cut
 
 sub OTRSBusinessIsAvailable {
     my ( $Self, %Param ) = @_;
 
-    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService');
+    return if $Self->{CloudServicesDisabled};
+
+    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
             OTRSBusiness => [
@@ -242,7 +253,7 @@ sub OTRSBusinessIsReinstallable {
 
 =item OTRSBusinessIsUpdateable()
 
-checks with cloud.otrs.com if the OTRSBusiness package is available in a newer version
+checks with C<cloud.otrs.com> if the OTRSBusiness package is available in a newer version
 than the one currently installed. The result of this check will be stored in the
 system_data table for offline usage.
 
@@ -251,10 +262,12 @@ system_data table for offline usage.
 sub OTRSBusinessIsUpdateable {
     my ( $Self, %Param ) = @_;
 
+    return 0 if $Self->{CloudServicesDisabled};
+
     my $Package = $Self->_GetOTRSBusinessPackageFromRepository();
     return if !$Package;
 
-    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService');
+    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
             OTRSBusiness => [
@@ -375,7 +388,7 @@ sub OTRSBusinessGetDependencies {
 
 =item OTRSBusinessEntitlementCheck()
 
-determines the OTRSBusiness entitlement status of this system as reported by cloud.otrs.com
+determines the OTRSBusiness entitlement status of this system as reported by C<cloud.otrs.com>
 and stores it in the system_data cache.
 
 Returns 1 if the cloud call was successful.
@@ -385,7 +398,9 @@ Returns 1 if the cloud call was successful.
 sub OTRSBusinessEntitlementCheck {
     my ( $Self, %Param ) = @_;
 
-    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService');
+    return if $Self->{CloudServicesDisabled};
+
+    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
             OTRSBusiness => [
@@ -444,22 +459,19 @@ sub OTRSBusinessEntitlementCheck {
 Returns the current entitlement status.
 
     my $Status = $OTRSBusinessObject->OTRSBusinessEntitlementStatus(
-        CallCloudService => 1,  # 0 or 1, call the cloud service before looking at the cache
+        CallCloudService => 1,              # 0 or 1, call the cloud service before looking at the cache
     );
 
-    $Status = 'entitled';   # everything is OK
-    $Status = 'warning';    # last check was OK, and we are in the waiting period
-    $Status = 'forbidden';  # not entitled (either because the server said so or because the last check was too long ago)
+    $Status = 'entitled';      # everything is OK
+    $Status = 'warning';       # last check was OK, and we are in the waiting period - show warning
+    $Status = 'warning-error'; # last check was OK, and we are past waiting period - show error message
+    $Status = 'forbidden';     # not entitled (either because the server said so or because the last check was too long ago)
 
 =cut
 
 sub OTRSBusinessEntitlementStatus {
     my ( $Self, %Param ) = @_;
 
-    if ( $Param{CallCloudService} ) {
-        $Self->OTRSBusinessEntitlementCheck();
-    }
-
     # If the system is not registered, it cannot have an OB permission.
     #   Also, the BusinessPermissionChecks will not work any more, so the permission
     #   would expire after our waiting period. But in this case we can immediately deny
@@ -471,6 +483,10 @@ sub OTRSBusinessEntitlementStatus {
         return 'forbidden';
     }
 
+    if ( $Param{CallCloudService} ) {
+        $Self->OTRSBusinessEntitlementCheck();
+    }
+
     # OK. Let's look at the system_data cache now and use it if appropriate
     my %EntitlementData = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGroupGet(
         Group => 'OTRSBusiness',
@@ -487,9 +503,12 @@ sub OTRSBusinessEntitlementStatus {
 
     my $SecondsSinceLastUpdate = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $LastUpdateSystemTime;
 
-    if ( $SecondsSinceLastUpdate > $NoConnectErrorPeriod ) {
+    if ( $SecondsSinceLastUpdate > $NoConnectBlockPeriod ) {
         return 'forbidden';
     }
+    if ( $SecondsSinceLastUpdate > $NoConnectErrorPeriod ) {
+        return 'warning-error';
+    }
     if ( $SecondsSinceLastUpdate > $NoConnectWarningPeriod ) {
         return 'warning';
     }
@@ -552,11 +571,11 @@ sub HandleBusinessPermissionCloudServiceResult {
     #   cloud.otrs.com cannot be made temporarily.
     my %StoreData = (
         BusinessPermission => $OperationResult->{Data}->{BusinessPermission} // 0,
-        ExpiryDate         => $OperationResult->{Data}->{ExpiryDate} // '',
+        ExpiryDate         => $OperationResult->{Data}->{ExpiryDate}         // '',
         LastUpdateTime     => $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
             SystemTime => $Kernel::OM->Get('Kernel::System::Time')->SystemTime()
         ),
-        AgentSessionLimit             => $OperationResult->{Data}->{AgentSessionLimit} // 0,
+        AgentSessionLimit             => $OperationResult->{Data}->{AgentSessionLimit}             // 0,
         AgentSessionLimitPriorWarning => $OperationResult->{Data}->{AgentSessionLimitPriorWarning} // 0,
     );
 
@@ -596,7 +615,7 @@ sub HandleBusinessVersionCheckCloudServiceResult {
 
     my %StoreData = (
         LatestVersionForCurrentFramework => $OperationResult->{Data}->{LatestVersionForCurrentFramework} // '',
-        FrameworkUpdateAvailable         => $OperationResult->{Data}->{FrameworkUpdateAvailable} // '',
+        FrameworkUpdateAvailable         => $OperationResult->{Data}->{FrameworkUpdateAvailable}         // '',
     );
 
     my $SystemDataObject = $Kernel::OM->Get('Kernel::System::SystemData');
@@ -626,7 +645,9 @@ sub HandleBusinessVersionCheckCloudServiceResult {
 sub _OTRSBusinessFileGet {
     my ( $Self, %Param ) = @_;
 
-    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService');
+    return if $Self->{CloudServicesDisabled};
+
+    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
             OTRSBusiness => [
@@ -665,15 +686,43 @@ downloads and installs OTRSBusiness.
 sub OTRSBusinessInstall {
     my ( $Self, %Param ) = @_;
 
+    my %Response = (
+        Success => 0,
+    );
+
     my $PackageString = $Self->_OTRSBusinessFileGet();
-    return if !$PackageString;
+    return %Response if !$PackageString;
+
+    my $PackageObject = $Kernel::OM->Get('Kernel::System::Package');
+
+    # Parse package structure.
+    my %Structure = $PackageObject->PackageParse(
+        String    => $PackageString,
+        FromCloud => 1,
+    );
+
+    my $FrameworkCheck = $PackageObject->_CheckFramework(
+        Framework  => $Structure{Framework},
+        NoLog      => 1,
+        ResultType => 'HASH',
+    );
+
+    # Check result type of _CheckFramework() for compatibility reasons.
+    if (
+        ref $FrameworkCheck eq 'HASH'
+        && !$FrameworkCheck->{Success}
+        )
+    {
+        $FrameworkCheck->{ShowBlock} = 'IncompatibleInfo';
+        return %{$FrameworkCheck};
+    }
 
     my $Install = $Kernel::OM->Get('Kernel::System::Package')->PackageInstall(
         String    => $PackageString,
         FromCloud => 1,
     );
 
-    return $Install if !$Install;
+    return %Response if !$Install;
 
     # now that we know that OTRSBusiness has been installed,
     # we can just preset the cache instead of just swiping it.
@@ -684,12 +733,14 @@ sub OTRSBusinessInstall {
         Value => 1,
     );
 
-    return $Install;
+    $Response{Success} = 1;
+
+    return %Response;
 }
 
 =item OTRSBusinessReinstall()
 
-reinstalls OTRSBusiness from local repository.
+re-installs OTRSBusiness from local repository.
 
 =cut
 
@@ -720,13 +771,46 @@ downloads and updates OTRSBusiness.
 sub OTRSBusinessUpdate {
     my ( $Self, %Param ) = @_;
 
+    my %Response = (
+        Success => 0,
+    );
+
     my $PackageString = $Self->_OTRSBusinessFileGet();
     return if !$PackageString;
 
-    return $Kernel::OM->Get('Kernel::System::Package')->PackageUpgrade(
+    my $PackageObject = $Kernel::OM->Get('Kernel::System::Package');
+
+    # Parse package structure.
+    my %Structure = $PackageObject->PackageParse(
         String    => $PackageString,
         FromCloud => 1,
     );
+
+    my $FrameworkCheck = $PackageObject->_CheckFramework(
+        Framework  => $Structure{Framework},
+        NoLog      => 1,
+        ResultType => 'HASH',
+    );
+
+    # Check result type of _CheckFramework() for compatibility reasons.
+    if (
+        ref $FrameworkCheck eq 'HASH'
+        && !$FrameworkCheck->{Success}
+        )
+    {
+        $FrameworkCheck->{ShowBlock} = 'IncompatibleInfo';
+        return %{$FrameworkCheck};
+    }
+
+    my $Upgrade = $Kernel::OM->Get('Kernel::System::Package')->PackageUpgrade(
+        String    => $PackageString,
+        FromCloud => 1,
+    );
+
+    return %Response if !$Upgrade;
+
+    $Response{Success} = 1;
+    return %Response;
 }
 
 =item OTRSBusinessUninstall()
@@ -816,6 +900,70 @@ sub OTRSBusinessUninstall {
     return $Uninstall;
 }
 
+=item OTRSBusinessCommandNextUpdateTimeSet()
+
+Set the next update time for the given command in the system data table storage.
+
+    my $Success = $OTRSBusinessObject->OTRSBusinessCommandNextUpdateTimeSet(
+        Command => 'AvailabilityCheck',
+    );
+
+Returns 1 if the next update time was set successfully.
+
+=cut
+
+sub OTRSBusinessCommandNextUpdateTimeSet {
+    my ( $Self, %Param ) = @_;
+
+    return if !$Param{Command};
+
+    my $Key = "OTRSBusiness::$Param{Command}::NextUpdateTime";
+
+    my $SystemDataObject = $Kernel::OM->Get('Kernel::System::SystemData');
+
+    my $NextUpdateTime = $SystemDataObject->SystemDataGet(
+        Key => $Key,
+    );
+
+    # set the default next update seconds offset
+    my $NextUpdateSecondsOffset = 60 * 60 * 24;
+
+    # generate a random seconds offset, if no next update time exists
+    if ( !$NextUpdateTime ) {
+
+        # create the random numbers
+        my $RandomHour   = int 20 + rand 23 - 20;
+        my $RandomMinute = int rand 60;
+
+        # create the random seconds offset
+        $NextUpdateSecondsOffset = 60 * 60 * $RandomHour + ( 60 * $RandomMinute );
+    }
+
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
+    my $CalculatedNextUpdateTime = $TimeObject->SystemTime2TimeStamp(
+        SystemTime => $TimeObject->SystemTime() + $NextUpdateSecondsOffset,
+    );
+
+    if ( defined $NextUpdateTime ) {
+        $SystemDataObject->SystemDataUpdate(
+            Key    => $Key,
+            Value  => $CalculatedNextUpdateTime,
+            UserID => 1,
+        );
+    }
+    else {
+        $SystemDataObject->SystemDataAdd(
+            Key    => $Key,
+            Value  => $CalculatedNextUpdateTime,
+            UserID => 1,
+        );
+    }
+
+    return 1;
+}
+
 sub _GetOTRSBusinessPackageFromRepository {
     my ( $Self, %Param ) = @_;
 
