@@ -1,6 +1,5 @@
 # --
-# Kernel/System/SupportDataCollector/Plugin/Database/mssql/Version.pm - system data collector plugin
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::DB',
 );
 
 sub GetDisplayPath {
-    return 'Database';
+    return Translatable('Database');
 }
 
 sub Run {
@@ -37,31 +38,19 @@ sub Run {
 
     if ($Version) {
         $Self->AddResultInformation(
-            Label => 'Database Version',
+            Label => Translatable('Database Version'),
             Value => $Version,
         );
     }
     else {
         $Self->AddResultProblem(
-            Label   => 'Database Version',
+            Label   => Translatable('Database Version'),
             Value   => $Version,
-            Message => "Could not determine database version.",
+            Message => Translatable("Could not determine database version."),
         );
     }
 
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
