@@ -1,7 +1,6 @@
 #!/usr/bin/perl
 # --
-# scripts/restore.pl - the restore script
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -10,12 +9,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -28,17 +27,9 @@ use FindBin qw($RealBin);
 use lib dirname($RealBin);
 use lib dirname($RealBin) . "/Kernel/cpan-lib";
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.18 $) [1];
-
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
+use Kernel::System::ObjectManager;
 
 # get options
 my %Opts;
@@ -46,8 +37,8 @@ my $DB     = '';
 my $DBDump = '';
 getopt( 'hbd', \%Opts );
 if ( exists $Opts{h} ) {
-    print "restore.pl <Revision $VERSION> - restore script\n";
-    print "Copyright (C) 2001-2013 OTRS AG, http://otrs.com/\n";
+    print "restore.pl - restore script\n";
+    print "Copyright (C) 2001-2018 OTRS AG, http://otrs.com/\n";
     print "usage: restore.pl -b /data_backup/<TIME>/ -d /opt/otrs/\n";
     exit 1;
 }
@@ -76,22 +67,23 @@ if ( -e "$Opts{b}/Config.tar.gz" ) {
 }
 
 # create common objects
-my %CommonObject;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-Restore',
-    %CommonObject,
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-restore.pl',
+    },
 );
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
-my $DatabaseHost = $CommonObject{ConfigObject}->Get('DatabaseHost');
-my $Database     = $CommonObject{ConfigObject}->Get('Database');
-my $DatabaseUser = $CommonObject{ConfigObject}->Get('DatabaseUser');
-my $DatabasePw   = $CommonObject{ConfigObject}->Get('DatabasePw');
-my $DatabaseDSN  = $CommonObject{ConfigObject}->Get('DatabaseDSN');
-my $ArticleDir   = $CommonObject{ConfigObject}->Get('ArticleDir');
+
+my $DatabaseHost = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseHost');
+my $Database     = $Kernel::OM->Get('Kernel::Config')->Get('Database');
+my $DatabaseUser = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseUser');
+my $DatabasePw   = $Kernel::OM->Get('Kernel::Config')->Get('DatabasePw');
+my $DatabaseDSN  = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseDSN');
+my $ArticleDir   = $Kernel::OM->Get('Kernel::Config')->Get('ArticleDir');
+
+# decrypt pw (if needed)
+if ( $DatabasePw =~ m/^\{(.*)\}$/ ) {
+    $DatabasePw = $Kernel::OM->Get('Kernel::System::DB')->_Decrypt($1);
+}
 
 # check db backup support
 if ( $DatabaseDSN =~ m/:mysql/i ) {
@@ -101,6 +93,9 @@ if ( $DatabaseDSN =~ m/:mysql/i ) {
 elsif ( $DatabaseDSN =~ m/:pg/i ) {
     $DB     = 'PostgreSQL';
     $DBDump = 'psql';
+    if ( $DatabaseDSN !~ m/host=/i ) {
+        $DatabaseHost = ''
+    }
 }
 else {
     print STDERR "ERROR: Can't backup, no database dump support!\n";
@@ -122,38 +117,36 @@ for my $CMD ( 'cp', 'tar', $DBDump ) {
 }
 
 # check database env
-if ( $CommonObject{DBObject} ) {
-    if ( $DB =~ m/mysql/i ) {
-        $CommonObject{DBObject}->Prepare( SQL => "SHOW TABLES" );
-        my $Check = 0;
-        while ( my @RowTmp = $CommonObject{DBObject}->FetchrowArray() ) {
-            $Check++;
-        }
-        if ($Check) {
-            print STDERR
-                "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
-            exit 1;
-        }
+if ( $DB =~ m/mysql/i ) {
+    $Kernel::OM->Get('Kernel::System::DB')->Prepare( SQL => "SHOW TABLES" );
+    my $Check = 0;
+    while ( my @RowTmp = $Kernel::OM->Get('Kernel::System::DB')->FetchrowArray() ) {
+        $Check++;
     }
-    else {
-        $CommonObject{DBObject}->Prepare(
-            SQL =>
-                "SELECT table_name FROM information_schema.tables WHERE table_catalog = 'otrs' AND table_schema = 'public'",
-        );
-        my $Check = 0;
-        while ( my @RowTmp = $CommonObject{DBObject}->FetchrowArray() ) {
-            $Check++;
-        }
-        if ($Check) {
-            print STDERR
-                "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
-            exit 1;
-        }
+    if ($Check) {
+        print STDERR
+            "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
+        exit 1;
+    }
+}
+else {
+    $Kernel::OM->Get('Kernel::System::DB')->Prepare(
+        SQL =>
+            "SELECT table_name FROM information_schema.tables WHERE table_catalog = 'otrs' AND table_schema = 'public'",
+    );
+    my $Check = 0;
+    while ( my @RowTmp = $Kernel::OM->Get('Kernel::System::DB')->FetchrowArray() ) {
+        $Check++;
+    }
+    if ($Check) {
+        print STDERR
+            "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
+        exit 1;
     }
 }
 
 # restore
-my $Home = $CommonObject{ConfigObject}->Get('Home');
+my $Home = $Kernel::OM->Get('Kernel::Config')->Get('Home');
 chdir($Home);
 
 # extract application
@@ -202,12 +195,21 @@ if ( $DB =~ m/mysql/i ) {
     }
 }
 else {
+    if ($DatabaseHost) {
+        $DatabaseHost = "-h $DatabaseHost"
+    }
+
     if ( -e "$Opts{b}/DatabaseBackup.sql.gz" ) {
         print "decompresses SQL-file ...\n";
         system("gunzip $Opts{b}/DatabaseBackup.sql.gz");
+
+        # set password via environment variable if there is one
+        if ($DatabasePw) {
+            $ENV{'PGPASSWORD'} = $DatabasePw;
+        }
         print "cat SQL-file into $DB database\n";
         system(
-            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser -W'$DatabasePw' -h$DatabaseHost $Database"
+            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser $DatabaseHost $Database"
         );
         print "compress SQL-file...\n";
         system("gzip $Opts{b}/DatabaseBackup.sql");
@@ -215,9 +217,14 @@ else {
     elsif ( -e "$Opts{b}/DatabaseBackup.sql.bz2" ) {
         print "decompresses SQL-file ...\n";
         system("bunzip2 $Opts{b}/DatabaseBackup.sql.bz2");
+
+        # set password via environment variable if there is one
+        if ($DatabasePw) {
+            $ENV{'PGPASSWORD'} = $DatabasePw;
+        }
         print "cat SQL-file into $DB database\n";
         system(
-            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser -W'$DatabasePw' -h$DatabaseHost $Database"
+            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser $DatabaseHost $Database"
         );
         print "compress SQL-file...\n";
         system("bzip2 $Opts{b}/DatabaseBackup.sql");
