@@ -1,8 +1,5 @@
 // --
-// Core.Agent.Admin.SysConfig.js - provides the special module functions for the AdminSysConfig
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-// --
-// $Id: Core.Agent.Admin.SysConfig.js,v 1.2 2011-02-17 21:22:11 en Exp $
+// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -16,22 +13,30 @@ Core.Agent = Core.Agent || {};
 Core.Agent.Admin = Core.Agent.Admin || {};
 
 /**
- * @namespace
- * @exports TargetNS as Core.Agent.Admin.SysConfig
+ * @namespace Core.Agent.Admin.SysConfig
+ * @memberof Core.Agent.Admin
+ * @author OTRS AG
  * @description
  *      This namespace contains the special module functions for the SysConfig module.
  */
 Core.Agent.Admin.SysConfig = (function (TargetNS) {
     /**
+     * @name Init
+     * @memberof Core.Agent.Admin.SysConfig
      * @function
-     * @return nothing
-     *      This function initializes the special module functions
+     * @description
+     *      Initializes SysConfig screen.
      */
     TargetNS.Init = function () {
-        $('#AdminSysConfig h3 input:checkbox').click(function () {
+        $('#AdminSysConfig h3 input[type="checkbox"]').click(function () {
             $(this).parent('h3').parent('fieldset').toggleClass('Invalid');
         });
+
+        // don't allow editing disabled fields
+        $('#AdminSysConfig').on('focus', '.Invalid input', function() {
+            $(this).blur();
+        });
     };
 
     return TargetNS;
-}(Core.Agent.Admin.SysConfig || {}));
\ No newline at end of file
+}(Core.Agent.Admin.SysConfig || {}));
