@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -79,6 +79,9 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
                 // Update signature if needed.
                 if ($('#Dest').val() !== '') {
                     SignatureURL = Core.Config.Get('Baselink') + 'Action=' + Core.Config.Get('Action') + ';Subaction=Signature;Dest=' + $('#Dest').val() + ';SelectedCustomerUser=' + $('#SelectedCustomerUser').val();
+                    if (!Core.Config.Get('SessionIDCookie')) {
+                        SignatureURL += ';' + Core.Config.Get('SessionName') + '=' + Core.Config.Get('SessionID');
+                    }
                     $('#Signature').attr('src', SignatureURL);
                 }
             }
@@ -431,7 +434,10 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
     };
 
     function htmlDecode(Text){
-        return Text.replace(/&amp;/g, '&');
+        return Text.replace(/&amp;/g, '&')
+            .replace(/&quot;/g, '"')
+            .replace(/&lt;/g, '<')
+            .replace(/&gt;/g, '>');
     }
 
     /**
@@ -461,6 +467,9 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
         if (CustomerValue === '') {
             return false;
         }
+        else {
+            CustomerValue = htmlDecode(CustomerValue);
+        }
 
         // check for duplicated entries
         $('[class*=CustomerTicketText]').each(function() {
@@ -556,7 +565,7 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
         }
 
         // return value to search field
-        $('#' + Field).val('').focus();
+        $('#' + Field).val('');
 
         CheckPhoneCustomerCountLimit();
 
